@@ -12,16 +12,16 @@ from ton import TonlibClient
 from .utils import *
 
 
-async def _get_client():
+async def _get_client(ls: int):
     TonlibClient.enable_unaudited_binaries()
-    client = TonlibClient(ls_index=2)
+    client = TonlibClient(ls_index=ls)
     await client.init_tonlib()
     # await client.set_verbosity_level(5)
     return client
 
 
-def get_client():
-    client = asyncio.get_event_loop().run_until_complete(_get_client())
+def get_client(ls: int = 0):
+    client = asyncio.get_event_loop().run_until_complete(_get_client(ls))
     return client
 
 
